===============================
DataProvider
===============================


.. image:: https://img.shields.io/pypi/v/dataprovider.svg
        :target: https://pypi.python.org/pypi/dataprovider

.. image:: https://img.shields.io/travis/tartavull/dataprovider.svg
        :target: https://travis-ci.org/tartavull/dataprovider


Deep learning platform-independent volumetric data provider for training 3D convolutional network.


* Free software: MIT license
* Documentation: https://tartavull.github.io/dataprovider


Features
--------

* TODO
